@@ -24,6 +24,7 @@
 #include "eventview.h"
 #include "viewcalendar.h"
 #include "helper.h"
+
 #include "prefs.h"
 #include "prefs_base.h" // for enums
 
@@ -55,23 +56,29 @@ using namespace EventViews;
 
 //-----------------------------------------------------------------------------
 
-QPixmap *AgendaItem::alarmPxmp = Q_NULLPTR;
-QPixmap *AgendaItem::recurPxmp = Q_NULLPTR;
-QPixmap *AgendaItem::readonlyPxmp = Q_NULLPTR;
-QPixmap *AgendaItem::replyPxmp = Q_NULLPTR;
-QPixmap *AgendaItem::groupPxmp = Q_NULLPTR;
-QPixmap *AgendaItem::groupPxmpTent = Q_NULLPTR;
-QPixmap *AgendaItem::organizerPxmp = Q_NULLPTR;
-QPixmap *AgendaItem::eventPxmp = Q_NULLPTR;
+QPixmap *AgendaItem::alarmPxmp = nullptr;
+QPixmap *AgendaItem::recurPxmp = nullptr;
+QPixmap *AgendaItem::readonlyPxmp = nullptr;
+QPixmap *AgendaItem::replyPxmp = nullptr;
+QPixmap *AgendaItem::groupPxmp = nullptr;
+QPixmap *AgendaItem::groupPxmpTent = nullptr;
+QPixmap *AgendaItem::organizerPxmp = nullptr;
+QPixmap *AgendaItem::eventPxmp = nullptr;
 
 //-----------------------------------------------------------------------------
 
 AgendaItem::AgendaItem(EventView *eventView, const MultiViewCalendar::Ptr &calendar,
-                       const KCalCore::Incidence::Ptr &item,
-                       int itemPos, int itemCount,
-                       const KDateTime &qd, bool isSelected, QWidget *parent)
-    : QWidget(parent), mEventView(eventView), mCalendar(calendar), mIncidence(item),
-      mOccurrenceDateTime(qd), mValid(true), mCloned(false), mSelected(isSelected), mSpecialEvent(false)
+                       const KCalCore::Incidence::Ptr &item, int itemPos, int itemCount,
+                       const QDateTime &qd, bool isSelected, QWidget *parent)
+    : QWidget(parent)
+    , mEventView(eventView)
+    , mCalendar(calendar)
+    , mIncidence(item)
+    , mOccurrenceDateTime(qd)
+    , mValid(true)
+    , mCloned(false)
+    , mSelected(isSelected)
+    , mSpecialEvent(false)
 {
     if (!mIncidence) {
         mValid = false;
@@ -79,12 +86,14 @@ AgendaItem::AgendaItem(EventView *eventView, const MultiViewCalendar::Ptr &calen
     }
 
     mIncidence = Incidence::Ptr(mIncidence->clone());
-    if (mIncidence->customProperty("KABC", "BIRTHDAY") == QLatin1String("YES") ||
-            mIncidence->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
-        const int years = EventViews::yearDiff(mIncidence->dtStart().date(), qd.toTimeSpec(mEventView->preferences()->timeSpec()).date());
+    if (mIncidence->customProperty("KABC", "BIRTHDAY") == QLatin1String("YES")
+        || mIncidence->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
+        const int years
+            = EventViews::yearDiff(mIncidence->dtStart().date(), qd.toLocalTime().date());
         if (years > 0) {
             mIncidence->setReadOnly(false);
-            mIncidence->setSummary(i18np("%2 (1 year)", "%2 (%1 years)", years, mIncidence->summary()));
+            mIncidence->setSummary(i18np("%2 (1 year)", "%2 (%1 years)", years,
+                                         mIncidence->summary()));
             mIncidence->setReadOnly(true);
             mCloned = true;
         }
@@ -98,8 +107,8 @@ AgendaItem::AgendaItem(EventView *eventView, const MultiViewCalendar::Ptr &calen
     mIconGroup = false;
     mIconGroupTent = false;
     mIconOrganizer = false;
-    mMultiItemInfo = Q_NULLPTR;
-    mStartMoveInfo = Q_NULLPTR;
+    mMultiItemInfo = nullptr;
+    mStartMoveInfo = nullptr;
 
     mItemPos = itemPos;
     mItemCount = itemCount;
@@ -136,8 +145,8 @@ void AgendaItem::updateIcons()
             mIconGroupTent = false;
             mIconOrganizer = true;
         } else {
-            KCalCore::Attendee::Ptr me =
-                mIncidence->attendeeByMails(mEventView->kcalPreferences()->allEmails());
+            KCalCore::Attendee::Ptr me
+                = mIncidence->attendeeByMails(mEventView->kcalPreferences()->allEmails());
 
             if (me) {
                 if (me->status() == KCalCore::Attendee::NeedsAction && me->RSVP()) {
@@ -201,7 +210,7 @@ bool AgendaItem::dissociateFromMultiItem()
         nextItem->setMultiItem(firstItem, prevItem, nextItem->prevMultiItem(), lastItem);
     }
     delete mMultiItemInfo;
-    mMultiItemInfo = Q_NULLPTR;
+    mMultiItemInfo = nullptr;
     return true;
 }
 
@@ -232,14 +241,14 @@ int AgendaItem::cellWidth() const
     return mCellXRight - mCellXLeft + 1;
 }
 
-void AgendaItem::setOccurrenceDateTime(const KDateTime &qd)
+void AgendaItem::setOccurrenceDateTime(const QDateTime &qd)
 {
     mOccurrenceDateTime = qd;
 }
 
 QDate AgendaItem::occurrenceDate() const
 {
-    return mOccurrenceDateTime.toTimeSpec(mEventView->preferences()->timeSpec()).date();
+    return mOccurrenceDateTime.toLocalTime().date();
 }
 
 void AgendaItem::setCellXY(int X, int YTop, int YBottom)
@@ -286,10 +295,10 @@ bool AgendaItem::isMultiItem() const
 AgendaItem::QPtr AgendaItem::prependMoveItem(const AgendaItem::QPtr &e)
 {
     if (!e) {
-        return Q_NULLPTR;
+        return nullptr;
     }
 
-    AgendaItem::QPtr first = Q_NULLPTR, last = Q_NULLPTR;
+    AgendaItem::QPtr first = nullptr, last = nullptr;
     if (isMultiItem()) {
         first = mMultiItemInfo->mFirstMultiItem;
         last = mMultiItemInfo->mLastMultiItem;
@@ -301,7 +310,7 @@ AgendaItem::QPtr AgendaItem::prependMoveItem(const AgendaItem::QPtr &e)
         last = this;
     }
 
-    e->setMultiItem(Q_NULLPTR, Q_NULLPTR, first, last);
+    e->setMultiItem(nullptr, nullptr, first, last);
     first->setMultiItem(e, e, first->nextMultiItem(), first->lastMultiItem());
 
     AgendaItem::QPtr tmp = first->nextMultiItem();
@@ -314,7 +323,7 @@ AgendaItem::QPtr AgendaItem::prependMoveItem(const AgendaItem::QPtr &e)
         e->mStartMoveInfo = new MultiItemInfo(*mStartMoveInfo);
 //    e->moveInfo()->mFirstMultiItem = moveInfo()->mFirstMultiItem;
 //    e->moveInfo()->mLastMultiItem = moveInfo()->mLastMultiItem;
-        e->moveInfo()->mPrevMultiItem = Q_NULLPTR;
+        e->moveInfo()->mPrevMultiItem = nullptr;
         e->moveInfo()->mNextMultiItem = first;
     }
 
@@ -327,10 +336,10 @@ AgendaItem::QPtr AgendaItem::prependMoveItem(const AgendaItem::QPtr &e)
 AgendaItem::QPtr AgendaItem::appendMoveItem(const AgendaItem::QPtr &e)
 {
     if (!e) {
-        return Q_NULLPTR;
+        return nullptr;
     }
 
-    AgendaItem::QPtr first = Q_NULLPTR, last = Q_NULLPTR;
+    AgendaItem::QPtr first = nullptr, last = nullptr;
     if (isMultiItem()) {
         first = mMultiItemInfo->mFirstMultiItem;
         last = mMultiItemInfo->mLastMultiItem;
@@ -342,7 +351,7 @@ AgendaItem::QPtr AgendaItem::appendMoveItem(const AgendaItem::QPtr &e)
         last = this;
     }
 
-    e->setMultiItem(first, last, Q_NULLPTR, Q_NULLPTR);
+    e->setMultiItem(first, last, nullptr, nullptr);
     AgendaItem::QPtr tmp = first;
 
     while (tmp) {
@@ -356,7 +365,7 @@ AgendaItem::QPtr AgendaItem::appendMoveItem(const AgendaItem::QPtr &e)
 //    e->moveInfo()->mFirstMultiItem = moveInfo()->mFirstMultiItem;
 //    e->moveInfo()->mLastMultiItem = moveInfo()->mLastMultiItem;
         e->moveInfo()->mPrevMultiItem = last;
-        e->moveInfo()->mNextMultiItem = Q_NULLPTR;
+        e->moveInfo()->mNextMultiItem = nullptr;
     }
     if (last && last->moveInfo()) {
         last->moveInfo()->mNextMultiItem = e;
@@ -378,18 +387,18 @@ AgendaItem::QPtr AgendaItem::removeMoveItem(const AgendaItem::QPtr &e)
         }
         if (first == e) {
             first = first->nextMultiItem();
-            first->setMultiItem(Q_NULLPTR, Q_NULLPTR, first->nextMultiItem(), first->lastMultiItem());
+            first->setMultiItem(nullptr, nullptr, first->nextMultiItem(), first->lastMultiItem());
         }
         if (last == e) {
             last = last->prevMultiItem();
-            last->setMultiItem(last->firstMultiItem(), last->prevMultiItem(), Q_NULLPTR, Q_NULLPTR);
+            last->setMultiItem(last->firstMultiItem(), last->prevMultiItem(), nullptr, nullptr);
         }
 
-        AgendaItem::QPtr tmp =  first;
+        AgendaItem::QPtr tmp = first;
         if (first == last) {
             delete mMultiItemInfo;
-            tmp = Q_NULLPTR;
-            mMultiItemInfo = Q_NULLPTR;
+            tmp = nullptr;
+            mMultiItemInfo = nullptr;
         }
         while (tmp) {
             next = tmp->nextMultiItem();
@@ -400,10 +409,10 @@ AgendaItem::QPtr AgendaItem::removeMoveItem(const AgendaItem::QPtr &e)
             if (e == prev) {
                 prev = prev->prevMultiItem();
             }
-            tmp->setMultiItem((tmp == first) ? Q_NULLPTR : first,
-                              (tmp == prev) ? Q_NULLPTR : prev,
-                              (tmp == next) ? Q_NULLPTR : next,
-                              (tmp == last) ? Q_NULLPTR : last);
+            tmp->setMultiItem((tmp == first) ? nullptr : first,
+                              (tmp == prev) ? nullptr : prev,
+                              (tmp == next) ? nullptr : next,
+                              (tmp == last) ? nullptr : last);
             tmp = tmp->nextMultiItem();
         }
     }
@@ -433,10 +442,10 @@ void AgendaItem::startMovePrivate()
         mStartMoveInfo->mPrevMultiItem = mMultiItemInfo->mPrevMultiItem;
         mStartMoveInfo->mNextMultiItem = mMultiItemInfo->mNextMultiItem;
     } else {
-        mStartMoveInfo->mFirstMultiItem = Q_NULLPTR;
-        mStartMoveInfo->mLastMultiItem = Q_NULLPTR;
-        mStartMoveInfo->mPrevMultiItem = Q_NULLPTR;
-        mStartMoveInfo->mNextMultiItem = Q_NULLPTR;
+        mStartMoveInfo->mFirstMultiItem = nullptr;
+        mStartMoveInfo->mLastMultiItem = nullptr;
+        mStartMoveInfo->mPrevMultiItem = nullptr;
+        mStartMoveInfo->mNextMultiItem = nullptr;
     }
     if (isMultiItem() && mMultiItemInfo->mNextMultiItem) {
         mMultiItemInfo->mNextMultiItem->startMovePrivate();
@@ -475,7 +484,7 @@ void AgendaItem::resetMovePrivate()
             if (!mStartMoveInfo->mFirstMultiItem) {
                 // This was the first multi-item when the move started, delete all previous
                 AgendaItem::QPtr toDel = mStartMoveInfo->mPrevMultiItem;
-                AgendaItem::QPtr nowDel = Q_NULLPTR;
+                AgendaItem::QPtr nowDel = nullptr;
                 while (toDel) {
                     nowDel = toDel;
                     if (nowDel->moveInfo()) {
@@ -483,13 +492,13 @@ void AgendaItem::resetMovePrivate()
                     }
                     Q_EMIT removeAgendaItem(nowDel);
                 }
-                mMultiItemInfo->mFirstMultiItem = Q_NULLPTR;
-                mMultiItemInfo->mPrevMultiItem = Q_NULLPTR;
+                mMultiItemInfo->mFirstMultiItem = nullptr;
+                mMultiItemInfo->mPrevMultiItem = nullptr;
             }
             if (!mStartMoveInfo->mLastMultiItem) {
                 // This was the last multi-item when the move started, delete all next
                 AgendaItem::QPtr toDel = mStartMoveInfo->mNextMultiItem;
-                AgendaItem::QPtr nowDel = Q_NULLPTR;
+                AgendaItem::QPtr nowDel = nullptr;
                 while (toDel) {
                     nowDel = toDel;
                     if (nowDel->moveInfo()) {
@@ -497,18 +506,19 @@ void AgendaItem::resetMovePrivate()
                     }
                     Q_EMIT removeAgendaItem(nowDel);
                 }
-                mMultiItemInfo->mLastMultiItem = Q_NULLPTR;
-                mMultiItemInfo->mNextMultiItem = Q_NULLPTR;
+                mMultiItemInfo->mLastMultiItem = nullptr;
+                mMultiItemInfo->mNextMultiItem = nullptr;
             }
 
-            if (mStartMoveInfo->mFirstMultiItem == Q_NULLPTR && mStartMoveInfo->mLastMultiItem == Q_NULLPTR) {
+            if (mStartMoveInfo->mFirstMultiItem == nullptr
+                && mStartMoveInfo->mLastMultiItem == nullptr) {
                 // it was a single-day event before we started the move.
                 delete mMultiItemInfo;
-                mMultiItemInfo = Q_NULLPTR;
+                mMultiItemInfo = nullptr;
             }
         }
         delete mStartMoveInfo;
-        mStartMoveInfo = Q_NULLPTR;
+        mStartMoveInfo = nullptr;
     }
     Q_EMIT showAgendaItem(this);
     if (nextMultiItem()) {
@@ -531,7 +541,7 @@ void AgendaItem::endMovePrivate()
         // if first, delete all previous
         if (!firstMultiItem() || firstMultiItem() == this) {
             AgendaItem::QPtr toDel = mStartMoveInfo->mPrevMultiItem;
-            AgendaItem::QPtr nowDel = Q_NULLPTR;
+            AgendaItem::QPtr nowDel = nullptr;
             while (toDel) {
                 nowDel = toDel;
                 if (nowDel->moveInfo()) {
@@ -543,7 +553,7 @@ void AgendaItem::endMovePrivate()
         // if last, delete all next
         if (!lastMultiItem() || lastMultiItem() == this) {
             AgendaItem::QPtr toDel = mStartMoveInfo->mNextMultiItem;
-            AgendaItem::QPtr nowDel = Q_NULLPTR;
+            AgendaItem::QPtr nowDel = nullptr;
             while (toDel) {
                 nowDel = toDel;
                 if (nowDel->moveInfo()) {
@@ -554,7 +564,7 @@ void AgendaItem::endMovePrivate()
         }
         // also delete the moving info
         delete mStartMoveInfo;
-        mStartMoveInfo = Q_NULLPTR;
+        mStartMoveInfo = nullptr;
         if (nextMultiItem()) {
             nextMultiItem()->endMovePrivate();
         }
@@ -613,7 +623,6 @@ void AgendaItem::expandRight(int dx)
 
 void AgendaItem::dragEnterEvent(QDragEnterEvent *e)
 {
-#ifndef KORG_NODND
     const QMimeData *md = e->mimeData();
     if (KCalUtils::ICalDrag::canDecode(md) || KCalUtils::VCalDrag::canDecode(md)) {
         // TODO: Allow dragging events/todos onto other events to create a relation
@@ -625,9 +634,6 @@ void AgendaItem::dragEnterEvent(QDragEnterEvent *e)
     } else {
         e->ignore();
     }
-#else
-    Q_UNUSED(e);
-#endif
 }
 
 void AgendaItem::addAttendee(const QString &newAttendee)
@@ -654,7 +660,6 @@ void AgendaItem::dropEvent(QDropEvent *e)
     // (not only file, also any other url!), then if it's a vcard,
     // otherwise check for attendees, then if the data is binary,
     // add a binary attachment.
-#ifndef KORG_NODND
     if (!mValid) {
         return;
     }
@@ -671,7 +676,7 @@ void AgendaItem::dropEvent(QDropEvent *e)
     KContacts::Addressee::List list;
 
     if (KContacts::VCardDrag::fromMimeData(md, list)) {
-        Q_FOREACH (const KContacts::Addressee &addressee, list) {
+        for (const KContacts::Addressee &addressee : qAsConst(list)) {
             QString em(addressee.fullEmail());
             if (em.isEmpty()) {
                 em = addressee.realName();
@@ -679,9 +684,6 @@ void AgendaItem::dropEvent(QDropEvent *e)
             addAttendee(em);
         }
     }
-#else
-    Q_UNUSED(e);
-#endif // KORG_NODND
 }
 
 QList<AgendaItem::QPtr> &AgendaItem::conflictItems()
@@ -692,8 +694,8 @@ QList<AgendaItem::QPtr> &AgendaItem::conflictItems()
 void AgendaItem::setConflictItems(const QList<AgendaItem::QPtr> &ci)
 {
     mConflictItems = ci;
-    QList<AgendaItem::QPtr>::iterator it;
-    for (it = mConflictItems.begin(); it != mConflictItems.end(); ++it) {
+    for (QList<AgendaItem::QPtr>::iterator it = mConflictItems.begin(), end(mConflictItems.end());
+         it != end; ++it) {
         (*it)->addConflictItem(this);
     }
 }
@@ -723,8 +725,8 @@ bool AgendaItem::overlaps(CellItem *o) const
     return false;
 }
 
-static void conditionalPaint(QPainter *p, bool condition, int &x, int y,
-                             int ft, const QPixmap &pxmp)
+static void conditionalPaint(QPainter *p, bool condition, int &x, int y, int ft,
+                             const QPixmap &pxmp)
 {
     if (condition) {
         p->drawPixmap(x, y, pxmp);
@@ -737,7 +739,7 @@ void AgendaItem::paintIcon(QPainter *p, int &x, int y, int ft)
     QString iconName;
     if (mIncidence->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
         mSpecialEvent = true;
-        iconName =  QStringLiteral("view-calendar-wedding-anniversary");
+        iconName = QStringLiteral("view-calendar-wedding-anniversary");
     } else if (mIncidence->customProperty("KABC", "BIRTHDAY") == QLatin1String("YES")) {
         mSpecialEvent = true;
         // We don't draw icon. The icon is drawn already, because it's the Akonadi::Collection's icon
@@ -758,7 +760,8 @@ void AgendaItem::paintIcons(QPainter *p, int &x, int y, int ft)
 
     if (icons.contains(EventViews::EventView::CalendarCustomIcon)) {
         const QString iconName = mCalendar->iconForIncidence(mIncidence);
-        if (!iconName.isEmpty() && iconName != QLatin1String("view-calendar") && iconName != QLatin1String("office-calendar")) {
+        if (!iconName.isEmpty() && iconName != QLatin1String("view-calendar")
+            && iconName != QLatin1String("office-calendar")) {
             conditionalPaint(p, true, x, y, ft, QIcon::fromTheme(iconName).pixmap(16, 16));
         }
     }
@@ -766,7 +769,7 @@ void AgendaItem::paintIcons(QPainter *p, int &x, int y, int ft)
     const bool isTodo = mIncidence && mIncidence->type() == Incidence::TypeTodo;
 
     if (isTodo && icons.contains(EventViews::EventView::TaskIcon)) {
-        const QString iconName = mIncidence->iconName(mOccurrenceDateTime.toTimeSpec(mIncidence->dtStart().timeSpec()));
+        const QString iconName = mIncidence->iconName(mOccurrenceDateTime.toLocalTime());
         conditionalPaint(p, !mSpecialEvent, x, y, ft, QIcon::fromTheme(iconName).pixmap(16, 16));
     }
 
@@ -827,25 +830,30 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
     // Also look at #17984
 
     if (!alarmPxmp) {
-        alarmPxmp     = new QPixmap(QIcon::fromTheme(QStringLiteral("task-reminder")).pixmap(16, 16));
-        recurPxmp     = new QPixmap(QIcon::fromTheme(QStringLiteral("appointment-recurring")).pixmap(16, 16));
-        readonlyPxmp  = new QPixmap(QIcon::fromTheme(QStringLiteral("object-locked")).pixmap(16, 16));
-        replyPxmp     = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-reply-sender")).pixmap(16, 16));
-        groupPxmp     = new QPixmap(QIcon::fromTheme(QStringLiteral("meeting-attending")).pixmap(16, 16));
-        groupPxmpTent = new QPixmap(QIcon::fromTheme(QStringLiteral("meeting-attending-tentative")).pixmap(16, 16));
-        organizerPxmp = new QPixmap(QIcon::fromTheme(QStringLiteral("meeting-organizer")).pixmap(16, 16));
+        alarmPxmp = new QPixmap(QIcon::fromTheme(QStringLiteral("task-reminder")).pixmap(16, 16));
+        recurPxmp
+            = new QPixmap(QIcon::fromTheme(QStringLiteral("appointment-recurring")).pixmap(16, 16));
+        readonlyPxmp
+            = new QPixmap(QIcon::fromTheme(QStringLiteral("object-locked")).pixmap(16, 16));
+        replyPxmp
+            = new QPixmap(QIcon::fromTheme(QStringLiteral("mail-reply-sender")).pixmap(16, 16));
+        groupPxmp
+            = new QPixmap(QIcon::fromTheme(QStringLiteral("meeting-attending")).pixmap(16, 16));
+        groupPxmpTent = new QPixmap(QIcon::fromTheme(QStringLiteral(
+                                                         "meeting-attending-tentative")).pixmap(16,
+                                                                                                16));
+        organizerPxmp
+            = new QPixmap(QIcon::fromTheme(QStringLiteral("meeting-organizer")).pixmap(16, 16));
     }
 
     QColor bgColor;
 
-    if (CalendarSupport::hasTodo(mIncidence) &&
-            !mEventView->preferences()->todosUseCategoryColors()) {
+    if (CalendarSupport::hasTodo(mIncidence)
+        && !mEventView->preferences()->todosUseCategoryColors()) {
         Todo::Ptr todo = CalendarSupport::todo(mIncidence);
         Q_ASSERT(todo);
-        const QDate dueDate =
-            todo->dtDue().toTimeSpec(CalendarSupport::KCalPrefs::instance()->timeSpec()).date();
-        const QDate today =
-            KDateTime::currentDateTime(CalendarSupport::KCalPrefs::instance()->timeSpec()).date();
+        const QDate dueDate = todo->dtDue().toLocalTime().date();
+        const QDate today = QDate::currentDate();
         const QDate occurrenceDate = this->occurrenceDate();
         if (todo->isOverdue() && today >= occurrenceDate) {
             bgColor = mEventView->preferences()->todoOverdueColor();
@@ -861,8 +869,8 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
         cat = categories.first();
     }
 
-    categoryColor = cat.isEmpty() ? CalendarSupport::KCalPrefs::instance()->unsetCategoryColor() :
-                    CalendarSupport::KCalPrefs::instance()->categoryColor(cat);
+    categoryColor = cat.isEmpty() ? CalendarSupport::KCalPrefs::instance()->unsetCategoryColor()
+                    : CalendarSupport::KCalPrefs::instance()->categoryColor(cat);
 
     QColor resourceColor = mResourceColor;
     if (!resourceColor.isValid()) {
@@ -871,29 +879,33 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
 
     QColor frameColor;
     // TODO PrefsBase enums should probably be redefined in Prefs
-    if (mEventView->preferences()->agendaViewColors() == PrefsBase::ResourceOnly ||
-            mEventView->preferences()->agendaViewColors() == PrefsBase::CategoryInsideResourceOutside) {
+    if (mEventView->preferences()->agendaViewColors() == PrefsBase::ResourceOnly
+        || mEventView->preferences()->agendaViewColors()
+        == PrefsBase::CategoryInsideResourceOutside) {
         frameColor = bgColor.isValid() ? bgColor : resourceColor;
     } else {
         frameColor = bgColor.isValid() ? bgColor : categoryColor;
     }
 
     if (!bgColor.isValid()) {
-        if (mEventView->preferences()->agendaViewColors() == PrefsBase::ResourceOnly ||
-                mEventView->preferences()->agendaViewColors() == PrefsBase::ResourceInsideCategoryOutside) {
+        if (mEventView->preferences()->agendaViewColors() == PrefsBase::ResourceOnly
+            || mEventView->preferences()->agendaViewColors()
+            == PrefsBase::ResourceInsideCategoryOutside) {
             bgColor = resourceColor;
         } else {
             bgColor = categoryColor;
         }
     }
 
-    if (cat.isEmpty() &&
-            mEventView->preferences()->agendaViewColors() == PrefsBase::ResourceInsideCategoryOutside) {
+    if (cat.isEmpty()
+        && mEventView->preferences()->agendaViewColors()
+        == PrefsBase::ResourceInsideCategoryOutside) {
         frameColor = bgColor;
     }
 
-    if (cat.isEmpty() &&
-            mEventView->preferences()->agendaViewColors() == PrefsBase::CategoryInsideResourceOutside) {
+    if (cat.isEmpty()
+        && mEventView->preferences()->agendaViewColors()
+        == PrefsBase::CategoryInsideResourceOutside) {
         bgColor = frameColor;
     }
 
@@ -908,7 +920,7 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
     }
 
     if (mSelected) {
-        bgColor = bgColor.light(EventView::BRIGHTNESS_FACTOR);
+        bgColor = bgColor.lighter(EventView::BRIGHTNESS_FACTOR);
     }
 
     const QColor textColor = EventViews::getTextColor(bgColor);
@@ -931,31 +943,31 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
     QString shortH;
     QString longH;
     if (!isMultiItem()) {
-        shortH = QLocale::system().toString(mIncidence->dateTime(KCalCore::Incidence::RoleDisplayStart).
-                                            toTimeSpec(mEventView->preferences()->timeSpec()).time(), QLocale::ShortFormat);
+        shortH = QLocale().toString(mIncidence->dateTime(
+                                        KCalCore::Incidence::RoleDisplayStart).toLocalTime().time(),
+                                    QLocale::ShortFormat);
 
         if (CalendarSupport::hasEvent(mIncidence)) {
             longH = i18n("%1 - %2",
                          shortH,
-                         QLocale::system().toString(
-                             mIncidence->dateTime(KCalCore::Incidence::RoleEnd).toTimeSpec(
-                                 mEventView->preferences()->timeSpec()).time(), QLocale::ShortFormat));
+                         QLocale().toString(mIncidence->dateTime(KCalCore::Incidence::RoleEnd).
+                                            toLocalTime().time(), QLocale::ShortFormat));
         } else {
             longH = shortH;
         }
     } else if (!mMultiItemInfo->mFirstMultiItem) {
-        shortH = QLocale::system().toString(
-                     mIncidence->dtStart().toTimeSpec(mEventView->preferences()->timeSpec()).time(), QLocale::ShortFormat);
+        shortH
+            = QLocale().toString(mIncidence->dtStart().toLocalTime().time(), QLocale::ShortFormat);
         longH = shortH;
     } else {
-        shortH = QLocale::system().toString(
-                     mIncidence->dateTime(KCalCore::Incidence::RoleEnd).toTimeSpec(
-                         mEventView->preferences()->timeSpec()).time(), QLocale::ShortFormat);
+        shortH = QLocale().toString(mIncidence->dateTime(
+                                        KCalCore::Incidence::RoleEnd).toLocalTime().time(),
+                                    QLocale::ShortFormat);
         longH = i18n("- %1", shortH);
     }
 
     KWordWrap ww = KWordWrap::formatText(
-                       fm, QRect(0, 0, width() - (2 * margin), -1), 0, mLabelText);
+        fm, QRect(0, 0, width() - (2 * margin), -1), 0, mLabelText);
     int th = ww.boundingRect().height();
 
     int hlHeight = qMax(fm.boundingRect(longH).height(),
@@ -964,7 +976,7 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
                                   qMax(readonlyPxmp->height(),
                                        qMax(replyPxmp->height(),
                                             qMax(groupPxmp->height(),
-                                                    organizerPxmp->height()))))));
+                                                 organizerPxmp->height()))))));
 
     const bool completelyRenderable = th < (height() - 2 * ft - 2 - hlHeight);
 
@@ -975,7 +987,7 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
     if ( //( singleLineHeight > height() - 4 ) ||
         (width() < 16)) {
         int x = qRound((width() - 16) / 2.0);
-        paintIcon(&p, x/*by-ref*/, margin, ft);
+        paintIcon(&p, x /*by-ref*/, margin, ft);
         return;
     }
 
@@ -985,11 +997,11 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
 
         if (mIncidence->allDay()) {
             x += visRect.left();
-            const int y =  qRound((height() - 16) / 2.0);
+            const int y = qRound((height() - 16) / 2.0);
             paintIcons(&p, x, y, ft);
             txtWidth = visRect.right() - margin - x;
         } else {
-            const int y =  qRound((height() - 16) / 2.0);
+            const int y = qRound((height() - 16) / 2.0);
             paintIcons(&p, x, y, ft);
             txtWidth = width() - margin - x;
         }
@@ -1001,9 +1013,9 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
 
     // case 3: enough for 2-5 lines, but not for the header.
     //         Also used for the middle days in multi-events
-    if (((!completelyRenderable) &&
-            ((height() - (2 * margin)) <= (5 * singleLineHeight))) ||
-            (isMultiItem() && mMultiItemInfo->mNextMultiItem && mMultiItemInfo->mFirstMultiItem)) {
+    if (((!completelyRenderable)
+         && ((height() - (2 * margin)) <= (5 * singleLineHeight)))
+        || (isMultiItem() && mMultiItemInfo->mNextMultiItem && mMultiItemInfo->mFirstMultiItem)) {
         int x = margin, txtWidth;
 
         if (mIncidence->allDay()) {
@@ -1016,7 +1028,7 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
         }
 
         ww = KWordWrap::formatText(
-                 fm, QRect(0, 0, txtWidth, (height() - (2 * margin))), 0, mLabelText);
+            fm, QRect(0, 0, txtWidth, (height() - (2 * margin))), 0, mLabelText);
 
         ww.drawText(&p, x, margin, Qt::AlignHCenter | KWordWrap::FadeOut);
         return;
@@ -1036,21 +1048,20 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
         longH.clear();
 
         if (const KCalCore::Event::Ptr event = CalendarSupport::event(mIncidence)) {
-            if (event->isMultiDay(mEventView->preferences()->timeSpec())) {
+            if (event->isMultiDay(QTimeZone::systemTimeZone())) {
                 // multi-day, all-day event
-                shortH =
-                    i18n("%1 - %2",
-                         QLocale::system().toString(
-                             mIncidence->dtStart().toTimeSpec(mEventView->preferences()->timeSpec()).date()),
-                         QLocale::system().toString(
-                             mIncidence->dateTime(KCalCore::Incidence::RoleEnd).toTimeSpec(
-                                 mEventView->preferences()->timeSpec()).date()));
+                shortH
+                    = i18n("%1 - %2",
+                           QLocale().toString(mIncidence->dtStart().toLocalTime().date()),
+                           QLocale().toString(mIncidence->dateTime(KCalCore::Incidence::RoleEnd).
+                                              toLocalTime().date()));
                 longH = shortH;
 
                 // paint headline
                 drawRoundedRect(
                     &p,
-                    QRect(fmargin, fmargin, width() - fmargin * 2, - fmargin * 2 + margin + hlHeight),
+                    QRect(fmargin, fmargin,
+                          width() - fmargin * 2, -fmargin * 2 + margin + hlHeight),
                     mSelected, frameColor, false, ft, roundTop, false);
             } else {
                 // single-day, all-day event
@@ -1058,7 +1069,8 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
                 // paint headline
                 drawRoundedRect(
                     &p,
-                    QRect(fmargin, fmargin, width() - fmargin * 2, - fmargin * 2 + margin + hlHeight),
+                    QRect(fmargin, fmargin,
+                          width() - fmargin * 2, -fmargin * 2 + margin + hlHeight),
                     mSelected, frameColor, false, ft, roundTop, false);
             }
         } else {
@@ -1067,7 +1079,7 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
             // paint headline
             drawRoundedRect(
                 &p,
-                QRect(fmargin, fmargin, width() - fmargin * 2, - fmargin * 2 + margin + hlHeight),
+                QRect(fmargin, fmargin, width() - fmargin * 2, -fmargin * 2 + margin + hlHeight),
                 mSelected, frameColor, false, ft, roundTop, false);
         }
 
@@ -1080,7 +1092,7 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
         // paint headline
         drawRoundedRect(
             &p,
-            QRect(fmargin, fmargin, width() - fmargin * 2, - fmargin * 2 + margin + hlHeight),
+            QRect(fmargin, fmargin, width() - fmargin * 2, -fmargin * 2 + margin + hlHeight),
             mSelected, frameColor, false, ft, roundTop, false);
 
         txtWidth = width() - margin - x;
@@ -1108,7 +1120,7 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
 
     // draw event text
     ww = KWordWrap::formatText(
-             fm, QRect(0, 0, txtWidth, height() - margin - y), 0, mLabelText);
+        fm, QRect(0, 0, txtWidth, height() - margin - y), 0, mLabelText);
 
     p.setBackground(QBrush(bgColor));
     p.setPen(textColor);
@@ -1119,12 +1131,10 @@ void AgendaItem::paintEvent(QPaintEvent *ev)
         ww.drawText(&p, eventX + (txtWidth - ww.boundingRect().width() - 2 * margin) / 2, y,
                     Qt::AlignHCenter | KWordWrap::FadeOut);
     }
-
 }
 
-void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect,
-                                 bool selected, const QColor &bgColor,
-                                 bool frame, int ft, bool roundTop,
+void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect, bool selected,
+                                 const QColor &bgColor, bool frame, int ft, bool roundTop,
                                  bool roundBottom)
 {
     Q_UNUSED(ft);
@@ -1176,7 +1186,7 @@ void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect,
         QLinearGradient gradient(QPointF(r.x(), r.y()), QPointF(r.x(), r.height()));
 
         if (selected) {
-            QColor top = bgColor.dark(250);
+            QColor top = bgColor.darker(250);
             top.setAlpha(40);
             gradient.setColorAt(0, top);
             gradient.setColorAt(1, QColor(255, 255, 255, 30));
@@ -1209,32 +1219,32 @@ void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect,
     QLinearGradient gradient(QPointF(r.x(), r.y()), QPointF(r.x(), r.height()));
 
     if (r.height() > 50) {
-        if (mIncidence->allDay() &&
-                mIncidence->dtStart() == mIncidence->dateTime(KCalCore::Incidence::RoleEnd) &&
-                CalendarSupport::hasEvent(mIncidence)) {
-            gradient.setColorAt(0, bgColor.light(130));
+        if (mIncidence->allDay()
+            && mIncidence->dtStart() == mIncidence->dateTime(KCalCore::Incidence::RoleEnd)
+            && CalendarSupport::hasEvent(mIncidence)) {
+            gradient.setColorAt(0, bgColor.lighter(130));
             qreal t = 1.0 - (r.height() - 18.0) / r.height();
-            gradient.setColorAt(t, bgColor.light(115));
+            gradient.setColorAt(t, bgColor.lighter(115));
             qreal b = (r.height() - 20.0) / r.height();
             gradient.setColorAt(b, bgColor);
         } else {
-            gradient.setColorAt(0, bgColor.light(115));
+            gradient.setColorAt(0, bgColor.lighter(115));
             qreal b = (r.height() - 20.0) / r.height();
             gradient.setColorAt(b, bgColor);
         }
-        gradient.setColorAt(1, bgColor.dark(110));
+        gradient.setColorAt(1, bgColor.darker(110));
     } else {
-        if (mIncidence->allDay() &&
-                mIncidence->dtStart() == mIncidence->dateTime(KCalCore::Incidence::RoleEnd) &&
-                !CalendarSupport::hasTodo(mIncidence)) {
-            gradient.setColorAt(0, bgColor.light(130));
-            gradient.setColorAt(0.35, bgColor.light(115));
+        if (mIncidence->allDay()
+            && mIncidence->dtStart() == mIncidence->dateTime(KCalCore::Incidence::RoleEnd)
+            && !CalendarSupport::hasTodo(mIncidence)) {
+            gradient.setColorAt(0, bgColor.lighter(130));
+            gradient.setColorAt(0.35, bgColor.lighter(115));
             gradient.setColorAt(0.65, bgColor);
         } else {
-            gradient.setColorAt(0, bgColor.light(115));
+            gradient.setColorAt(0, bgColor.lighter(115));
             gradient.setColorAt(0.65, bgColor);
         }
-        gradient.setColorAt(1, bgColor.dark(110));
+        gradient.setColorAt(1, bgColor.darker(110));
     }
 
     p->setBrush(gradient);
@@ -1263,11 +1273,9 @@ void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect,
         p->setBrushOrigin(r.x() + 8, r.y() + r.height() - 6);
         p->fillRect(QRect(r.x() + 8, r.y() + r.height() - 6, r.width() - 16, 6),
                     QBrush(bottomLines));
-
     }
 
     if (r.height() - 16 > 0) {
-
         QPixmap leftLines;
         QString key(QStringLiteral("ko_l"));
         if (!QPixmapCache::find(key, leftLines)) {
@@ -1304,7 +1312,9 @@ void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect,
     QPixmap topLeft;
     QString key = roundTop ? QStringLiteral("ko_tl") : QStringLiteral("ko_rtl");
     if (!QPixmapCache::find(key, topLeft)) {
-        topLeft = roundTop ? QPixmap(QStringLiteral(":/roundTopLeft.png")) : QPixmap(QStringLiteral(":/rectangularTopLeft.png"));
+        topLeft
+            = roundTop ? QPixmap(QStringLiteral(":/roundTopLeft.png")) : QPixmap(QStringLiteral(
+                                                                                     ":/rectangularTopLeft.png"));
         QPixmapCache::insert(key, topLeft);
     }
     p->drawPixmap(r.x(), r.y(), topLeft, 0, 0, lw, th);
@@ -1312,7 +1322,8 @@ void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect,
     QPixmap topRight;
     key = roundTop ? QStringLiteral("ko_tr") : QStringLiteral("ko_rtr");
     if (!QPixmapCache::find(key, topRight)) {
-        topRight = roundTop ? QPixmap(QStringLiteral(":/roundTopRight.png")) : QPixmap(QStringLiteral(":/rectangularTopRight.png"));
+        topRight = roundTop ? QPixmap(QStringLiteral(":/roundTopRight.png")) : QPixmap(QStringLiteral(
+                                                                                           ":/rectangularTopRight.png"));
         QPixmapCache::insert(key, topRight);
     }
     p->drawPixmap(r.x() + r.width() - rw, r.y(), topRight, 8 - rw, 0, rw, th);
@@ -1320,8 +1331,8 @@ void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect,
     QPixmap bottomLeft;
     key = roundBottom ? QStringLiteral("ko_bl") : QStringLiteral("ko_rbl");
     if (!QPixmapCache::find(key, bottomLeft)) {
-        bottomLeft = roundBottom ? QPixmap(QStringLiteral(":/roundBottomLeft.png")) :
-                     QPixmap(QStringLiteral(":/rectangularBottomLeft.png"));
+        bottomLeft = roundBottom ? QPixmap(QStringLiteral(":/roundBottomLeft.png"))
+                     : QPixmap(QStringLiteral(":/rectangularBottomLeft.png"));
         QPixmapCache::insert(key, bottomLeft);
     }
     p->drawPixmap(r.x(), r.y() + r.height() - bh, bottomLeft, 0, 8 - bh, lw, bh);
@@ -1329,8 +1340,8 @@ void AgendaItem::drawRoundedRect(QPainter *p, const QRect &rect,
     QPixmap bottomRight;
     key = roundBottom ? QStringLiteral("ko_br") : QStringLiteral("ko_rbr");
     if (!QPixmapCache::find(key, bottomRight)) {
-        bottomRight = roundBottom ? QPixmap(QStringLiteral(":/roundBottomRight.png")) :
-                      QPixmap(QStringLiteral(":/rectangularBottomRight.png"));
+        bottomRight = roundBottom ? QPixmap(QStringLiteral(":/roundBottomRight.png"))
+                      : QPixmap(QStringLiteral(":/rectangularBottomRight.png"));
         QPixmapCache::insert(key, bottomRight);
     }
     p->drawPixmap(r.x() + r.width() - rw, r.y() + r.height() - bh, bottomRight,
@@ -1360,11 +1371,9 @@ bool AgendaItem::event(QEvent *event)
                 helpEvent->globalPos(),
                 KCalUtils::IncidenceFormatter::toolTipStr(
                     mCalendar->displayName(mIncidence),
-                    mIncidence,
-                    occurrenceDate(), true, mEventView->preferences()->timeSpec()),
+                    mIncidence, occurrenceDate(), true),
                 this);
         }
     }
     return QWidget::event(event);
 }
-
